"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const is_1 = __importDefault(require("@sindresorhus/is"));
const argument_error_1 = require("../argument-error");
const base_predicate_1 = require("./base-predicate");
const not_1 = require("../operators/not");
/**
 * @hidden
 */
exports.validatorSymbol = Symbol('validators');
/**
 * @hidden
 */
class Predicate {
    constructor(type, context = {
        validators: []
    }) {
        this.context = context;
        this.addValidator({
            message: value => `Expected argument to be of type \`${type}\` but received type \`${is_1.default(value)}\``,
            validator: value => is_1.default[type](value)
        });
    }
    /**
     * @hidden
     */
    // tslint:disable completed-docs
    [base_predicate_1.testSymbol](value, main) {
        for (const { validator, message } of this.context.validators) {
            const result = validator(value);
            if (typeof result !== 'boolean' || !result) {
                // TODO: Modify the stack output to show the original `ow()` call instead of this `throw` statement
                throw new argument_error_1.ArgumentError(message(value, result), main);
            }
        }
    }
    /**
     * @hidden
     */
    get [exports.validatorSymbol]() {
        return this.context.validators;
    }
    /**
     * Invert the following validators.
     */
    get not() {
        return not_1.not(this);
    }
    /**
     * Test if the value matches a custom validation function. The validation function should return `true` if the value
     * passes the function. If the function either returns `false` or a string, the function fails and the string will be
     * used as error message.
     *
     * @param fn Validation function.
     */
    is(fn) {
        return this.addValidator({
            message: (value, error) => error || `Expected \`${value}\` to pass custom validation function`,
            validator: value => fn(value)
        });
    }
    /**
     * Register a new validator.
     *
     * @internal
     * @hidden
     * @param validator Validator to register.
     */
    addValidator(validator) {
        this.context.validators.push(validator);
        return this;
    }
}
exports.Predicate = Predicate;
//# sourceMappingURL=predicate.js.map